@@ -36,6 +36,8 @@ cvar_t *cl_http_filelists;
 cvar_t *cl_http_proxy;
 cvar_t *cl_http_max_connections;
 
+dlquirks_t dlquirks = { .error = false, .filelist = true, .gamedir = '\0' };
+
 typedef enum
 {
 	HTTPDL_ABORT_NONE,
@@ -47,10 +49,8 @@ static CURLM  *multi = NULL;
 static int handleCount = 0;
 static int pendingCount = 0;
 static int abortDownloads = HTTPDL_ABORT_NONE;
+static qboolean downloadingPak = false;
 static qboolean	httpDown = false;
-static qboolean downloadError = false;
-static qboolean downloadFilelist = true;
-static char downloadGamedir[MAX_QPATH];
 
 // --------
 
@@ -206,13 +206,13 @@ static void CL_StartHTTPDownload (dlqueue_t *entry, dlhandle_t *dl)
 		Com_sprintf (dl->filePath, sizeof(dl->filePath), "%s/%s", FS_Gamedir(), entry->quakePath);
 
 		// Full path to the remote file.
-		if (downloadGamedir[0] == '\0')
+		if (dlquirks.gamedir[0] == '\0')
 		{
 			Com_sprintf (tempFile, sizeof(tempFile), "/%s", entry->quakePath);
 		}
 		else
 		{
-			Com_sprintf (tempFile, sizeof(tempFile), "/%s/%s", downloadGamedir, entry->quakePath);
+			Com_sprintf (tempFile, sizeof(tempFile), "/%s/%s", dlquirks.gamedir, entry->quakePath);
 		}
 
 		CL_EscapeHTTPPath (tempFile, escapedFilePath);
@@ -594,7 +594,18 @@ static void CL_FinishHTTPDownload(void)
 				{
 					Com_Printf("HTTP download: %s - File Not Found\n", dl->queueEntry->quakePath);
 
-					// We got a 404, remove the target file...
+					// We got a 404, reset pak downloading state...
+					size_t len = strlen(dl->queueEntry->quakePath);
+
+					if (!strcmp(dl->queueEntry->quakePath + len - 4, ".pak")
+							|| !strcmp(dl->queueEntry->quakePath + len - 4, ".pk2")
+							|| !strcmp(dl->queueEntry->quakePath + len - 4, ".pk3")
+							|| !strcmp(dl->queueEntry->quakePath + len - 4, ".zip"))
+					{
+						downloadingPak = false;
+					}
+
+					// ...remove the target file...
 					if (isFile)
 					{
 						Sys_Remove(dl->filePath);
@@ -608,7 +619,7 @@ static void CL_FinishHTTPDownload(void)
 					// ...and communicate the error.
 					if (isFile)
 					{
-						downloadError = true;
+						dlquirks.error = true;
 						isFile = false;
 					}
 
@@ -637,7 +648,18 @@ static void CL_FinishHTTPDownload(void)
 			case CURLE_COULDNT_RESOLVE_PROXY:
 				Com_Printf("HTTP download: %s - Server broken, aborting\n", dl->queueEntry->quakePath);
 
-				// The download failed. Remove the temporary file...
+				// The download failed. Reset pak downloading state...
+				size_t len = strlen(dl->queueEntry->quakePath);
+
+				if (!strcmp(dl->queueEntry->quakePath + len - 4, ".pak")
+						|| !strcmp(dl->queueEntry->quakePath + len - 4, ".pk2")
+						|| !strcmp(dl->queueEntry->quakePath + len - 4, ".pk3")
+						|| !strcmp(dl->queueEntry->quakePath + len - 4, ".zip"))
+				{
+					downloadingPak = false;
+				}
+
+				// remove the temporary file...
 				if (isFile)
 				{
 					Sys_Remove(dl->filePath);
@@ -666,7 +688,7 @@ static void CL_FinishHTTPDownload(void)
 			default:
 				Com_Printf ("HTTP download: cURL error - %s\n", qcurl_easy_strerror(result));
 
-				// The download failed. Remove the temporary file...
+				// The download failed. Clear the Remove the temporary file...
 				if (isFile)
 				{
 					Sys_Remove(dl->filePath);
@@ -697,6 +719,7 @@ static void CL_FinishHTTPDownload(void)
 			{
 				FS_AddPAKFromGamedir(dl->queueEntry->quakePath);
 				CL_ReVerifyHTTPQueue ();
+				downloadingPak = false;
 			}
 
 			CL_RemoveFromQueue(dl->queueEntry);
@@ -773,6 +796,16 @@ static void CL_StartNextHTTPDownload(void)
 
 			CL_StartHTTPDownload(q, dl);
 
+			size_t len = strlen(q->quakePath);
+
+			if (!strcmp(q->quakePath + len - 4, ".pak")
+					|| !strcmp(q->quakePath + len - 4, ".pk2")
+					|| !strcmp(q->quakePath + len - 4, ".pk3")
+					|| !strcmp(q->quakePath + len - 4, ".zip"))
+			{
+				downloadingPak = true;
+			}
+
 			break;
 		}
 	}
@@ -930,7 +963,7 @@ void CL_SetHTTPServer (const char *URL)
 	abortDownloads = HTTPDL_ABORT_NONE;
 	handleCount = pendingCount = 0;
 	cls.downloadServerRetry[0] = 0;
-	downloadError = false;
+	dlquirks.error = false;
 
 	// Remove trailing / from URL if any.
 	size_t urllen = strlen(URL);
@@ -1007,10 +1040,10 @@ qboolean CL_QueueHTTPDownload(const char *quakePath, qboolean gamedirForFilelist
 	// the generic(!) filelist.
 	qboolean needList = false;
 
-	if (downloadFilelist && cl_http_filelists->value)
+	if (dlquirks.filelist && cl_http_filelists->value)
 	{
 		needList = true;
-		downloadFilelist = false;
+		dlquirks.filelist = false;
 	}
 
 	// Queue the download.
@@ -1041,7 +1074,7 @@ qboolean CL_QueueHTTPDownload(const char *quakePath, qboolean gamedirForFilelist
 		{
 			char fileList[MAX_OSPATH];
 
-			Com_sprintf(fileList, sizeof(fileList), "/%s/%s", downloadGamedir, ".filelist");
+			Com_sprintf(fileList, sizeof(fileList), "/%s%s", dlquirks.gamedir, ".filelist");
 			CL_QueueHTTPDownload(fileList, false);
 		}
 		else
@@ -1063,13 +1096,13 @@ qboolean CL_QueueHTTPDownload(const char *quakePath, qboolean gamedirForFilelist
 		char listPath[MAX_OSPATH];
 		char filePath[MAX_OSPATH];
 
-		if (downloadGamedir[0] == '\0')
+		if (dlquirks.gamedir[0] == '\0')
 		{
 			Com_sprintf (filePath, sizeof(filePath), "/%s", quakePath);
 		}
 		else
 		{
-			Com_sprintf (filePath, sizeof(filePath), "/%s/%s", downloadGamedir, quakePath);
+			Com_sprintf (filePath, sizeof(filePath), "/%s/%s", dlquirks.gamedir, quakePath);
 		}
 
 		COM_StripExtension (filePath, listPath);
@@ -1102,42 +1135,6 @@ qboolean CL_PendingHTTPDownloads(void)
 	return pendingCount + handleCount;
 }
 
-/*
- * Checks if there was an error. Returns
- * true if yes, and false if not.
- */
-qboolean CL_CheckHTTPError(void)
-{
-	if (downloadError)
-	{
-		downloadError = false;
-		return true;
-	}
-	else
-	{
-		return false;
-	}
-}
-
-/*
- * Enables generic file list download starting
- * with the next file. Yes, this is dirty.
- */
-void CL_HTTP_EnableGenericFilelist(void)
-{
-	downloadFilelist = true;
-}
-
-/*
- * Sets the gamedir to be used by the URL
- * generator to determine the remote file
- * path.
- */
-void CL_HTTP_SetDownloadGamedir(const char *gamedir)
-{
-	Q_strlcpy(downloadGamedir, gamedir, sizeof(downloadGamedir));
-}
-
 /*
  * Calls CURL to perform the actual downloads.
  * Must be called every frame, otherwise CURL
@@ -1176,7 +1173,8 @@ void CL_RunHTTPDownloads(void)
 
 	// Not enough downloads running, start some more.
 	if (pendingCount && abortDownloads == HTTPDL_ABORT_NONE &&
-			handleCount < cl_http_max_connections->value)
+			handleCount < cl_http_max_connections->value &&
+			!downloadingPak)
 	{
 		CL_StartNextHTTPDownload();
 	}
