@@ -233,10 +233,10 @@ RecursiveLightPoint(mnode_t *node, vec3_t start, vec3_t end)
 			for (maps = 0; maps < MAX_LIGHTMAPS_PER_SURFACE && surf->styles[maps] != 255;
 				 maps++)
 			{
-				for (i = 0; i < 3; i++)
+				for (int j = 0; j < 3; j++)
 				{
-					scale[i] = r_modulate->value *
-							   gl3_newrefdef.lightstyles[surf->styles[maps]].rgb[i];
+					scale[j] = r_modulate->value *
+							   gl3_newrefdef.lightstyles[surf->styles[maps]].rgb[j];
 				}
 
 				pointcolor[0] += lightmap[0] * scale[0] * (1.0 / 255);
