@@ -203,7 +203,7 @@ R_SetUpFrustumIndexes (void)
 			}
 		}
 
-	// FIXME: do just once at start
+		// FIXME: do just once at start
 		pfrustum_indexes[i] = pindex;
 		pindex += 6;
 	}
@@ -385,10 +385,6 @@ R_SetupFrame (void)
 	r_polycount = 0;
 	r_drawnpolycount = 0;
 	r_amodels_drawn = 0;
-	r_outofsurfaces = 0;
-	r_outofverts = 0;
-	r_outofedges = 0;
-	r_outoftriangles = 0;
 
 	// d_setup
 	d_minmip = sw_mipcap->value;
