@@ -18,6 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 #include <assert.h>
+#include <limits.h>
 #include "header/local.h"
 
 #define AFFINE_SPANLET_SIZE      16
@@ -48,7 +49,7 @@ static emitpoint_t	outverts[MAXWORKINGVERTS+3];
 
 static int	s_minindex, s_maxindex;
 
-static void R_DrawPoly(int iswater);
+static void R_DrawPoly(int iswater, espan_t *spans);
 
 /*
 ** R_DrawSpanletOpaque
@@ -589,7 +590,7 @@ R_ClipPolyFace (int nump, clipplane_t *pclipplane)
 /*
 ** R_PolygonDrawSpans
 */
-// PGM - iswater was qboolean. changed to allow passing more flags
+// iswater was qboolean. changed to allow passing more flags
 static void
 R_PolygonDrawSpans(espan_t *pspan, int iswater )
 {
@@ -600,13 +601,11 @@ R_PolygonDrawSpans(espan_t *pspan, int iswater )
 
 	s_spanletvars.pbase = cacheblock;
 
-	//PGM
 	if ( iswater & SURF_WARP)
 		r_turb_turb = sintable + ((int)(r_newrefdef.time*SPEED)&(CYCLE-1));
 	else
 		// iswater & SURF_FLOWING
 		r_turb_turb = blanktable;
-	//PGM
 
 	sdivzspanletstepu = d_sdivzstepu * AFFINE_SPANLET_SIZE;
 	tdivzspanletstepu = d_tdivzstepu * AFFINE_SPANLET_SIZE;
@@ -910,7 +909,7 @@ R_PolygonScanRightEdge(espan_t *s_polygon_spans)
 /*
 ** R_ClipAndDrawPoly
 */
-// PGM - isturbulent was qboolean. changed to int to allow passing more flags
+// isturbulent was qboolean. changed to int to allow passing more flags
 void
 R_ClipAndDrawPoly ( float alpha, int isturbulent, qboolean textured )
 {
@@ -1021,7 +1020,7 @@ R_ClipAndDrawPoly ( float alpha, int isturbulent, qboolean textured )
 	r_polydesc.nump = nump;
 	r_polydesc.pverts = outverts;
 
-	R_DrawPoly(isturbulent);
+	R_DrawPoly(isturbulent, vid_polygon_spans);
 }
 
 /*
@@ -1074,14 +1073,12 @@ R_BuildPolygonFromSurface(const entity_t *currententity, const model_t *currentm
 		VectorSubtract( vec3_origin, r_polydesc.vpn, r_polydesc.vpn );
 	}
 
-	// PGM 09/16/98
 	if ( fa->texinfo->flags & (SURF_WARP|SURF_FLOWING) )
 	{
 		r_polydesc.pixels       = fa->texinfo->image->pixels[0];
 		r_polydesc.pixel_width  = fa->texinfo->image->width;
 		r_polydesc.pixel_height = fa->texinfo->image->height;
 	}
-	// PGM 09/16/98
 	else
 	{
 		surfcache_t *scache;
@@ -1153,20 +1150,18 @@ R_PolygonCalculateGradients (void)
 **
 ** This should NOT be called externally since it doesn't do clipping!
 */
-// PGM - iswater was qboolean. changed to support passing more flags
+// iswater was qboolean. changed to support passing more flags
 static void
-R_DrawPoly(int iswater)
+R_DrawPoly(int iswater, espan_t *spans)
 {
 	int		i, nump;
 	float		ymin, ymax;
 	emitpoint_t	*pverts;
-	espan_t		*spans;
-	spans = vid_polygon_spans;
 
 	// find the top and bottom vertices, and make sure there's at least one scan to
 	// draw
-	ymin = 999999.9;
-	ymax = -999999.9;
+	ymin = INT_MAX; // Set maximum values for world range
+	ymax = INT_MIN; // Set minimal values for world range
 	pverts = r_polydesc.pverts;
 
 	for (i=0 ; i<r_polydesc.nump ; i++)
@@ -1202,8 +1197,8 @@ R_DrawPoly(int iswater)
 	pverts[nump] = pverts[0];
 
 	R_PolygonCalculateGradients();
-	R_PolygonScanLeftEdge(vid_polygon_spans);
-	R_PolygonScanRightEdge(vid_polygon_spans);
+	R_PolygonScanLeftEdge(spans);
+	R_PolygonScanRightEdge(spans);
 
 	R_PolygonDrawSpans(spans, iswater);
 }
@@ -1225,20 +1220,11 @@ R_DrawAlphaSurfaces(const entity_t *currententity)
 	{
 		R_BuildPolygonFromSurface(currententity, currentmodel, s);
 
-		//=======
-		//PGM
-		//		if (s->texinfo->flags & SURF_TRANS66)
-		//			R_ClipAndDrawPoly( 0.60f, ( s->texinfo->flags & SURF_WARP) != 0, true );
-		//		else
-		//			R_ClipAndDrawPoly( 0.30f, ( s->texinfo->flags & SURF_WARP) != 0, true );
-
-		// PGM - pass down all the texinfo flags, not just SURF_WARP.
+		// pass down all the texinfo flags, not just SURF_WARP.
 		if (s->texinfo->flags & SURF_TRANS66)
 			R_ClipAndDrawPoly( 0.60f, (s->texinfo->flags & (SURF_WARP|SURF_FLOWING)), true );
 		else
 			R_ClipAndDrawPoly( 0.30f, (s->texinfo->flags & (SURF_WARP|SURF_FLOWING)), true );
-		//PGM
-		//=======
 
 		s = s->nextalphasurface;
 	}
