@@ -414,6 +414,11 @@ FS_FOpenFile(const char *name, fileHandle_t *f, qboolean gamedir_only)
 						           handle->name, pack->name);
 					}
 
+					// save the name with *correct case* in the handle
+					// (relevant for savegames, when starting map with wrong case but it's still found
+					//  because it's from pak, but save/bla/MAPname.sav/sv2 will have wrong case and can't be found then)
+					Q_strlcpy(handle->name, pack->files[i].name, sizeof(handle->name));
+
 					if (pack->pak)
 					{
 						/* PAK */
@@ -1654,6 +1659,18 @@ FS_BuildGameSpecificSearchPath(char *dir)
 #endif
 }
 
+// returns the filename used to open f, but (if opened from pack) in correct case
+// returns NULL if f is no valid handle
+const char* FS_GetFilenameForHandle(fileHandle_t f)
+{
+	fsHandle_t* fsh = FS_GetFileByHandle(f);
+	if(fsh)
+	{
+		return fsh->name;
+	}
+	return NULL;
+}
+
 // --------
 
 void FS_AddDirToRawPath (const char *dir, qboolean create) {
