@@ -376,7 +376,7 @@ Qcommon_Init(int argc, char **argv)
 
 #ifndef DEDICATED_ONLY
 void
-Qcommon_Frame(int msec)
+Qcommon_Frame(int usec)
 {
 	// Used for the dedicated server console.
 	char *s;
@@ -413,20 +413,10 @@ Qcommon_Frame(int msec)
 	qboolean packetframe = true;
 
 	/* A rendererframe runs the renderer, but not the
-	   client. The minimal interval is about 1000
-	   microseconds. */
+	   client or the server. The minimal interval is
+	   about 1000 microseconds. */
 	qboolean renderframe = true;
 
-	// Average time needed to process a render frame.
-	static int avgrenderframetime;
-	static int renderframetimes[60];
-	static qboolean last_was_renderframe;
-
-	// Average time needed to process a packet frame.
-	static int avgpacketframetime;
-	static int packetframetimes[60];
-	static qboolean last_was_packetframe;
-
 
 	/* Tells the client to shutdown.
 	   Used by the signal handlers. */
@@ -437,7 +427,7 @@ Qcommon_Frame(int msec)
 
 
 	/* In case of ERR_DROP we're jumping here. Don't know
-	   if that' really save but it seems to work. So leave
+	   if that's really save but it seems to work. So leave
 	   it alone. */
 	if (setjmp(abortframe))
 	{
@@ -478,11 +468,11 @@ Qcommon_Frame(int msec)
 	// Timing debug crap. Just for historical reasons.
 	if (fixedtime->value)
 	{
-		msec = (int)fixedtime->value;
+		usec = (int)fixedtime->value;
 	}
 	else if (timescale->value)
 	{
-		msec *= timescale->value;
+		usec *= timescale->value;
 	}
 
 
@@ -498,10 +488,10 @@ Qcommon_Frame(int msec)
 	}
 
 
-	/* We can at maximum render 1000 frames, because the minimum
-	   frametime of the engine is 1 millisecond. And of course we
+	/* We can render 1000 frames at maximum, because the minimum
+	   frametime of the client is 1 millisecond. And of course we
 	   need to render something, the framerate can never be less
-	   then 1. Cap vid_maxfps between 999 and 1.a */
+	   then 1. Cap vid_maxfps between 1 and 999. */
 	if (vid_maxfps->value > 999 || vid_maxfps->value < 1)
 	{
 		Cvar_SetValue("vid_maxfps", 999);
@@ -521,7 +511,7 @@ Qcommon_Frame(int msec)
 	curtime = Sys_Milliseconds();
 
 
-	// Calculate target packet- and renderframerate.
+	// Calculate target and renderframerate.
 	if (R_IsVSyncActive())
 	{
 		rfps = GLimp_GetRefreshRate();
@@ -542,104 +532,48 @@ Qcommon_Frame(int msec)
 	   Add a security magin of 5%, e.g. 60fps * 0.95 = 57fps. */
 	pfps = (cl_maxfps->value > (rfps * 0.95)) ? floor(rfps * 0.95) : cl_maxfps->value;
 
-	/* Calculate average time spend to process a render
-	   frame. This is highly depended on the GPU and the
-	   scenes complexity. Take last 60 render frames
-	   into account and add a security margin of 1%.
-
-	   Note: We don't take only pure render frames, but
-	   all render frames into account because on the
-	   popular 60hz displays at least all render frames
-	   are also packet frames if the vsync is enabled. */
-	if (last_was_renderframe)
-	{
-		int measuredframes = 0;
-		static int renderframenum;
-
-		avgrenderframetime = 0;
-		renderframetimes[renderframenum] = msec;
-
-		for (int i = 0; i < 60; i++)
-		{
-			if (renderframetimes[i] != 0)
-			{
-				avgrenderframetime += renderframetimes[i];
-				measuredframes++;
-			}
-		}
-
-		avgrenderframetime /= measuredframes;
-		avgrenderframetime += (avgrenderframetime * 0.01f);
-
-		renderframenum++;
-
-		if (renderframenum > 59)
-		{
-			renderframenum = 0;
-		}
-
-		last_was_renderframe = false;
-	}
-
-	/* Calculate the average time spend to process a packet
-	   frame. Packet frames are mostly dependend on the CPU
-	   speed and the network delay. Take the last packet
-	   frames into account and add a security margin of 1%.
-
-	   Note: Like with the render frames we take all packet
-	   frames into account and not only pure packet frames.
-	   The reasons are the same, on popular 60hz displays
-	   most packet frames are also render frames.
-	   */
-	if (last_was_packetframe)
-	{
-		int measuredframes = 0;
-		static int packetframenum;
-
-		avgpacketframetime = 0;
-		packetframetimes[packetframenum] = msec;
-
-		for (int i = 0; i < 60; i++)
-		{
-			if (packetframetimes[i] != 0)
-			{
-				avgpacketframetime += packetframetimes[i];
-				measuredframes++;
-			}
-		}
-
-		avgpacketframetime /= measuredframes;
-		avgpacketframetime += (avgpacketframetime * 0.01f);
-
-		packetframenum++;
-
-		if (packetframenum > 59)
-		{
-			packetframenum = 0;
-		}
-
-		last_was_packetframe = false;
-	}
-
 
 	// Calculate timings.
-	packetdelta += msec;
-	renderdelta += msec;
-	clienttimedelta += msec;
-	servertimedelta += msec;
+	packetdelta += usec;
+	renderdelta += usec;
+	clienttimedelta += usec;
+	servertimedelta += usec;
 
-	if (!cl_timedemo->value) {
-		if (cl_async->value) {
-			// Network frames..
-			if (packetdelta < ((1000000.0f + avgpacketframetime) / pfps)) {
-				packetframe = false;
-			}
+	if (!cl_timedemo->value)
+	{
+		if (cl_async->value)
+		{
+			if (R_IsVSyncActive())
+			{
+				// Netwwork frames.
+				if (packetdelta < (0.8 * (1000000.0f / pfps)))
+				{
+					packetframe = false;
+				}
 
-			// Render frames.
-			if (renderdelta < ((1000000.0f + avgrenderframetime) / rfps)) {
-				renderframe = false;
+				// Render frames.
+				if (renderdelta < (0.8 * (1000000.0f / rfps)))
+				{
+					renderframe = false;
+				}
 			}
-		} else {
+			else
+			{
+				// Network frames.
+				if (packetdelta < (1000000.0f / pfps))
+				{
+					packetframe = false;
+				}
+
+				// Render frames.
+				if (renderdelta < (1000000.0f ) / rfps)
+				{
+					renderframe = false;
+				}
+			}
+		}
+		else
+		{
 			// Cap frames at target framerate.
 			if (renderdelta < (1000000.0f / rfps)) {
 				renderframe = false;
@@ -710,17 +644,15 @@ Qcommon_Frame(int msec)
 	// Reset deltas and mark frame.
 	if (packetframe) {
 		packetdelta = 0;
-		last_was_packetframe = true;
 	}
 
 	if (renderframe) {
 		renderdelta = 0;
-		last_was_renderframe = true;
 	}
 }
 #else
 void
-Qcommon_Frame(int msec)
+Qcommon_Frame(int usec)
 {
 	// For the dedicated server terminal console.
 	char *s;
@@ -763,11 +695,11 @@ Qcommon_Frame(int msec)
 	// Timing debug crap. Just for historical reasons.
 	if (fixedtime->value)
 	{
-		msec = (int)fixedtime->value;
+		usec = (int)fixedtime->value;
 	}
 	else if (timescale->value)
 	{
-		msec *= timescale->value;
+		usec *= timescale->value;
 	}
 
 
@@ -780,8 +712,8 @@ Qcommon_Frame(int msec)
 
 
 	// Calculate timings.
-	packetdelta += msec;
-	servertimedelta += msec;
+	packetdelta += usec;
+	servertimedelta += usec;
 
 
 	// Network frame time.
